API References
==============

Quick overview of core classes/function
---------------------------------------
- :class:`tetgenpy.TetgenIO <.TetgenIO>`: input and output of tetgen calls are done with this object.
- :class:`tetgenpy.PLC <.PLC>`: helper class for creating :class:`.TetgenIO`. Especially helpful for avoiding explicit indexing.
- :func:`tetgenpy.tetrahedralize <tetgenpy.gentet.tetrahedralize>`: the main function of tetgen.

Python API
----------
.. toctree::

   python_api
